==> antos0.48.tar.gz: antos0.48/kern/exec.c <==
/*
 * exec.c
 *
 * Copyright 200@, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * t@C̎s
 */


#include <sys/config.h>
#include <sys/types.h>
#include <sys/param.h>
#include <kern/fs.h>
#include <kern/mm.h>
#include <kern/interrupt.h>
#include <kern/loader.h>

#include <kern/test.h>
#include <kern/debug.h>


//#define DEBUG_EXEC 1
#ifdef DEBUG_EXEC
	#define STATIC
	#define INLINE
#else
	#define STATIC	static
	#define INLINE	inline
#endif


//================================== ʒ` ===========================================

//================================== O[oC|[g ===============================

//================================== PRIVATE ============================================

//================================== PUBLIC =============================================

int sys_exec(
	const char *path, 
	char **argv, 
	char **envp, 
	volatile SYSCALL4_FRAME frame)
{
	uint entryAddr;
	uint stackAddr;
	SYS_INFO *sys_info;
	int error;

	error = loadFile(path, argv, envp, &entryAddr, &stackAddr);
	if (error != NOERR) {
		return error;
	}

	/* X^bNɃVXeݒB */
	sys_info = (SYS_INFO*)(USER_ESP_BEG - sizeof(SYS_INFO));
	sys_info->lastAddr = getLastLinearAddr();

	/* VOiANV̏B */
	resetSignal(get_current_task()->signal_struct);

	/* t@C\̂̏B */
	initExecFs();

/* VXeR[t[̐ݒB */
	frame.es = USER_DATA_DES;
	frame.ds = USER_DATA_DES;
	frame.eip = entryAddr;
	frame.cs = USER_CODE_DES;
	frame.user_esp = stackAddr - sizeof(frame.para);
	frame.ss = USER_DATA_DES;

	return NOERR;
}

==> antos0.49.tar.gz: antos0.49/kern/exec.c <==
/*
 * exec.c
 *
 * Copyright 200@, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * եμ¹
 */


#include <sys/config.h>
#include <sys/types.h>
#include <sys/param.h>
#include <machine/mode_switch.h>
#include <kern/fs.h>
#include <kern/mm.h>
#include <kern/signal.h>
#include <kern/loader.h>

#include <kern/debug.h>


//#define DEBUG_EXEC 1
#ifdef DEBUG_EXEC
	#define STATIC
	#define INLINE
#else
	#define STATIC	static
	#define INLINE	inline
#endif


//==================================  ===========================================

//================================== Х륤ݡ ===============================

//================================== PRIVATE ============================================

//================================== PUBLIC =============================================

int sys_exec(
	const char *path, 
	char **argv, 
	char **envp, 
	volatile SYSCALL4_FRAME frame)
{
	uint entryAddr;
	uint stackAddr;
	SYS_INFO *sys_info;
	int error;

	error = loadFile(path, argv, envp, &entryAddr, &stackAddr);
	if (error != NOERR) {
		return error;
	}

	/* å˥ƥꡣ */
	sys_info = (SYS_INFO*)(USER_ESP_BEG - sizeof(SYS_INFO));
	sys_info->lastAddr = getLastLinearAddr();

	/* ʥ륢ν */
	resetSignal(get_current_task()->signal_struct);

	/* ե빽¤Τν */
	initExecFs();

/* ƥॳե졼ꡣ */
	frame.es = USER_DATA_DES;
	frame.ds = USER_DATA_DES;
	frame.eip = entryAddr;
	frame.cs = USER_CODE_DES;
	frame.user_esp = stackAddr - sizeof(frame.para);
	frame.ss = USER_DATA_DES;

	return NOERR;
}
